/*
 * nela - a Braille code trainer
 * Copyright (C) 2012  Enrique Matias-Sanchez <quique at unizar.es>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#include "mainwindow.h"
#include "perkinsWidget.h"
#include <QAction>
#include <QApplication>
#include <QMenu>
#include <QMenuBar>
#include <QMessageBox>
#include <QPointer>
#include <QStatusBar>

MainWindow::MainWindow()
{
    pw = new PerkinsWidget();
    setCentralWidget(pw);
    
    createActions();
    createMenus();
    createStatusBar();
}

void MainWindow::about()
{
    QPointer<QMessageBox> aboutBox = new QMessageBox(this);
    aboutBox->setTextFormat(Qt::RichText);

    aboutBox->setText(tr("<center><img src=\":/icons/hicolor/256x256/apps/nela.png\"/></img></center>"
                    "<h2>Nela %1</h2>"
                    "<p>Nela is a Braille code trainer.</p>"
                    "<p>Copyright &copy; 2012 Enrique Mat&iacute;as S&aacute;nchez."
                   ).arg(qApp->applicationVersion()));

    aboutBox->setWindowTitle(tr("About %1").arg(qApp->applicationName()));
    aboutBox->setIcon(QMessageBox::NoIcon);
    aboutBox->exec();
    delete aboutBox;
}

void MainWindow::updateStatusBar(QString message)
{
    statusLabel->setText(message);
}

void MainWindow::createActions()
{
    exitAction = new QAction(tr("E&xit"), this);
    exitAction->setIcon(QIcon::fromTheme(QLatin1String("application-exit")));
    exitAction->setShortcut(tr("Ctrl+Q"));
    exitAction->setStatusTip(tr("Exit the application"));
    exitAction->setMenuRole(QAction::QuitRole);
    connect(exitAction, SIGNAL(triggered()), this, SLOT(close()));

    aboutAction = new QAction(tr("&About %1").arg(QApplication::applicationName()), this);
    aboutAction->setIcon(windowIcon());
    aboutAction->setStatusTip(tr("Show the application's About box"));
    aboutAction->setMenuRole(QAction::AboutRole);
    connect(aboutAction, SIGNAL(triggered()), this, SLOT(about()));

//    aboutQtAction = new QAction(tr("About &Qt"), this);
//    aboutQtAction->setStatusTip(tr("Show the Qt library's About box"));
//    connect(aboutQtAction, SIGNAL(triggered()), qApp, SLOT(aboutQt()));
}

void MainWindow::createMenus()
{
    fileMenu = menuBar()->addMenu(tr("&File"));
    fileMenu->addAction(exitAction);

    menuBar()->addSeparator();

    helpMenu = menuBar()->addMenu(tr("&Help"));
    helpMenu->addAction(aboutAction);
//    helpMenu->addAction(aboutQtAction);
}

void MainWindow::createStatusBar()
{
    statusLabel = new QLabel();
    statusBar()->addWidget(statusLabel, 1);

    updateStatusBar(tr("Use keyboard's central row"));
}
